@@ -1,5 +1,5 @@
 # Copyright (c) 2001 Dominic Mitchell.
-# Portions Copyright (c) 2007-2009 Gavin Henry - <ghenry@suretecsystems.com>, 
+# Portions Copyright (c) 2007 Gavin Henry - <ghenry@suretecsystems>, 
 # Suretec Systems Ltd.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,6 @@ use strict;
 use vars qw( $VERSION );
 use base qw( Template::Plugin );
 
-use Template::Exception;
 use Net::LDAP;
 
 $VERSION = ( qw( $Revision: 1318 $ ) )[1];
@@ -67,7 +66,7 @@ sub connect {
 
     $host = shift
       || $params->{ host }
-      || $self->throw( "no ldap host specified" );
+      || return $self->_throw( "no ldap host specified" );
     $port = ( $host =~ m/:(\d+)$/ )[0]
       || $params->{ port }
       || getservbyname( "ldap", "tcp" )
@@ -76,7 +75,7 @@ sub connect {
     $pass = shift || $params->{ pass };
 
     my $ldap = Net::LDAP->new( $host, port => $port )
-      or return $self->throw( "ldap connect: $@" );
+      or return $self->_throw( "ldap connect: $@" );
     if ( $user || $pass ) {
         $ldap->bind( $user, password => $pass );
     }
@@ -94,16 +93,12 @@ sub search {
     my $params = ref $_[-1] eq 'HASH' ? pop( @_ ) : { @_ };
 
     my $mesg = $self->_ldap->search( %$params );
-    $self->throw( $mesg->error )
+    return $self->_throw( $mesg->error )
       if $mesg->code;
 
     return Template::Plugin::LDAP::Iterator->new( $mesg );
 }
 
-sub throw {
-	die Template::Exception->new( 'ldap', join('', @_) );
-}
-
 package Template::Plugin::LDAP::Iterator;
 
 use strict;
@@ -204,20 +199,11 @@ sub _fetchentry {
 
 package Template::Plugin::LDAP::Entry;
 
+use vars qw( $AUTOLOAD );
+
 sub new {
     my ( $class, $entry ) = @_;
     my $self = { _entry => $entry };
-    foreach my $attrib ( $entry->attributes(nooptions => 1)) {
-	no strict 'refs';
-	next if defined &{"$class\::\L$attrib"};
-	*{"$class\::\L$attrib"} = sub {
-		if ( $_[0]->{ _entry }->exists( $attrib ) ) {
-                	return $_[0]->{ _entry }->get_value( $attrib );
-		} else {
-			return "";
-		}
-	}
-    }
     bless $self, $class;
     return $self;
 }
@@ -227,6 +213,18 @@ sub dn {
     return $self->{ _entry }->dn;
 }
 
+sub AUTOLOAD {
+    my $self = shift;
+    ( my $var = $AUTOLOAD ) =~ s/.*:://;
+    my $val;
+    if ( $self->{ _entry }->exists( $var ) ) {
+        return $self->{ _entry }->get_value( $var );
+    }
+    else {
+        return "";
+    }
+}
+
 1;
 __END__
 
@@ -272,29 +270,14 @@ to do updates later, that functionality might be added.
 
 =head1 METHODS
 
-=head2 new
-
-=head2 connect
-
-=head2 search
-
-=head2 get_first
-
-=head2 get_next 
-
-=head2 get 
-
-=head2 get_all 
-
-=head2 dn 
+I will fill this in when I am less tired.
 
 =head1 AUTHOR
 
 Dominic Mitchell E<lt>dom@happygiraffe.netE<gt>
 
 =head1 MAINTAINER
-
-Suretec Systems Ltd., Gavin Henry E<lt>ghenry@suretecsystems.com<gt>
+Suretec Systems Ltd, Gavin Henry C<< <ghenry@suretecsystems.com> >>
 
 =head1 SEE ALSO
 
